systemtools.BenchmarkScoreMaker
===============================

.. abjad-lineage:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker

.. autoclass:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_bound_hairpin_score_01
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_bound_hairpin_score_02
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_bound_hairpin_score_03
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_hairpin_score_01
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_hairpin_score_02
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_hairpin_score_03
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_00
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_with_indicators_01
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_with_indicators_02
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_with_indicators_03
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_01
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_02
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_03
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_04
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_05
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_06
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_07
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_08
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_09
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__eq__
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__format__
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__hash__
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__ne__
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_bound_hairpin_score_01
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_bound_hairpin_score_02
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_bound_hairpin_score_03
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_hairpin_score_01
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_hairpin_score_02
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_hairpin_score_03
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_00
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_with_indicators_01
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_with_indicators_02
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_score_with_indicators_03
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_01
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_02
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_03
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_04
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_05
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_06
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_07
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_08
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.make_spanner_score_09
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__eq__
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__format__
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__hash__
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__ne__
   :noindex:

.. automethod:: abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker.__repr__
   :noindex:
